<div class="relative w-full{% if class %} {{ class }}{% endif %}">
  <canvas class="chart" data-type="bar" data-value="{{ data }}" {% if width %}width="{{ width }}"{% endif %} {% if height %}height="{{ height }}"{% endif %}></canvas>
</div>
